/*
 * importdialog.cpp
 *
 * (c) 2003-2004 by Jeremy Bowman <jmbowman@alum.mit.edu>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 */

#include <qfiledialog.h>
#include <qfileinfo.h>
#include <qinputdialog.h>
#include <qmessagebox.h>
#include <qstringlist.h>
#include "importdialog.h"
#include "qpeapplication.h"
#include "../csverror.h"
#include "../database.h"
#include "../importutils.h"
#include "../qqdialog.h"

ImportDialog::ImportDialog(int sourceType, Database *subject, QWidget *parent)
  : QObject(), db(subject), parentWidget(parent), source(sourceType)
{

}

ImportDialog::~ImportDialog()
{

}

bool ImportDialog::exec()
{
    QString filter;
    if (source == CSV_FILE) {
        filter = tr("Text files with comma separated values") + " (*.csv)";
    }
    else if (source == MOBILEDB_FILE) {
        filter = tr("MobileDB files") + " (*.pdb)";
    }
    else if (source == OPTION_LIST) {
        filter = QString::null;
    }
    else if (source == XML_FILE) {
        filter = tr("XML files") + " (*.xml)";
    }
    else {
        filter = tr("Images") + " (*.jpg *.jpeg *.png)";
    }
    QString file = QFileDialog::getOpenFileName(QPEApplication::documentDir(),
                                                filter, parentWidget,
                                                "import dialog",
                                                tr("Choose a file"));
    if (file.isEmpty()) {
        return FALSE;
    }
    else {
        QFileInfo info(file);
        QPEApplication::setDocumentDir(info.dirPath(TRUE));
        path = info.absFilePath();
    }

    QString encoding = "";
    if (source == CSV_FILE || source == OPTION_LIST) {
        QStringList encodings;
        encodings.append("UTF-8");
        encodings.append("Latin-1");
        bool ok;
        encoding = QInputDialog::getItem(tr("Import")
                                         + QQDialog::titleSuffix,
                                         tr("Text encoding") + ":",
                                         encodings, 0, FALSE, &ok,
                                         parentWidget);
        if (!ok) {
            return FALSE;
        }
    }

    QString error = "";
    QString data = "";
    if (source == CSV_FILE) {
        QStringList result = db->importFromCSV(file, encoding);
        int count = result.count();
        if (count > 0) {
            error = result[0];
        }
        if (count > 1) {
            data = result[1];
        }
    }
    else if (source == OPTION_LIST) {
        ImportUtils utils;
        error = utils.importTextLines(file, encoding, &options);
    }
    else if (source == MOBILEDB_FILE) {
        ImportUtils utils;
        error = utils.importMobileDB(file, db);
    }
    else if (source == XML_FILE) {
        ImportUtils utils;
        error = utils.importXML(file, db);
    }
    if (error != "") {
        if (data == "") {
            QMessageBox::warning(0, QQDialog::tr("PortaBase"), error);
        }
        else {
            CSVErrorDialog dialog(error, data, 0);
            dialog.exec();
        }
        return FALSE;
    }
    else {
        return TRUE;
    }
}

QStringList ImportDialog::getOptions()
{
    return options;
}

QString ImportDialog::getPath()
{
    return path;
}
